@@ -1,7 +1,7 @@
 package App::PlUtils;
 
-our $DATE = '2015-09-17'; # DATE
-our $VERSION = '0.10'; # VERSION
+our $DATE = '2016-07-20'; # DATE
+our $VERSION = '0.11'; # VERSION
 
 use 5.010001;
 use strict;
@@ -15,7 +15,7 @@ For convenience, if filename does not contain path separator, it will first be
 searched in the current directory, then in `PATH` (using `File::Which`).
 
 _
-    schema  => 'str*',
+    schema  => 'filename*',
     req     => 1,
     pos     => 0,
     completion => sub {
@@ -33,7 +33,7 @@ For convenience, if filename does not contain path separator, it will first be
 searched in the current directory, then in `PATH` (using `File::Which`).
 
 _
-    schema  => ['array*', of=>'str*', min_len=>1],
+    schema  => ['array*', of=>'filename*', min_len=>1],
     req     => 1,
     pos     => 0,
     greedy  => 1,
@@ -45,7 +45,7 @@ _
 };
 
 our $arg_module_single = {
-    schema => 'str*',
+    schema => 'perl::modname*',
     completion => sub {
         require Complete::Module;
         my %args = @_;
@@ -69,7 +69,7 @@ App::PlUtils - Command-line utilities related to Perl scripts
 
 =head1 VERSION
 
-This document describes version 0.10 of App::PlUtils (from Perl distribution App-PlUtils), released on 2015-09-17.
+This document describes version 0.11 of App::PlUtils (from Perl distribution App-PlUtils), released on 2016-07-20.
 
 =head1 SYNOPSIS
 
@@ -103,6 +103,22 @@ similar to L<pmversion> from L<App::PMUtils> distribution, and so on.
 True. The main point of these utilities is shell tab completion, to save
 typing.
 
+=head1 HOMEPAGE
+
+Please visit the project's homepage at L<https://metacpan.org/release/App-PlUtils>.
+
+=head1 SOURCE
+
+Source repository is at L<https://github.com/perlancar/perl-App-PlUtils>.
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-PlUtils>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =head1 SEE ALSO
 
 Below is the list of distributions that provide CLI utilities for various
@@ -126,29 +142,13 @@ L<App::ProgUtils>, utilities related to programs.
 
 L<App::WeaverUtils>, utilities related to L<Pod::Weaver>.
 
-=head1 HOMEPAGE
-
-Please visit the project's homepage at L<https://metacpan.org/release/App-PlUtils>.
-
-=head1 SOURCE
-
-Source repository is at L<https://github.com/perlancar/perl-App-PlUtils>.
-
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-PlUtils>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
